package Perinci::Sub::Gen::AccessTable::I18N;

use parent 'Locale::Maketext';
use Locale::Maketext::Lexicon;

our $VERSION = '0.27'; # VERSION

1;
# ABSTRACT: Project class for Perinci::Sub::Gen:AccessTable

__END__

=pod

=encoding utf-8

=head1 NAME

Perinci::Sub::Gen::AccessTable::I18N - Project class for Perinci::Sub::Gen:AccessTable

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Gen-AccessTable>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Gen-AccessTable>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
http://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-Gen-AccessTabl
e

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
